import { MaxHeapTree } from '@algo-js/heap-tree';
export interface Queue<T> {
    queue: (item: T, priority: number) => this;
    dequeue: () => T | undefined;
    readonly size: number;
}
export declare class PriorityQueue<T> extends MaxHeapTree<T> implements Queue<T> {
    /**
     * @returns {number}
     */
    readonly size: number;
    static defaultPriority: number;
    /**
     * @param {Map} priorities
     * @param {*} a
     * @param {*} b
     * @returns {number}
     */
    static priorityCompareFn<T>(priorities: Map<T, number>, a: T, b: T): number;
    private priorities;
    constructor();
    /**
     * @param {*} element
     * @param {number} priority
     * @returns {PriorityQueue}
     */
    queue(element: T, priority?: number): this;
    /**
     * @returns {*}
     */
    dequeue(): T | undefined;
    /**
     * @private
     * @deprecated
     */
    add(element: T): this;
    /**
     * @private
     * @deprecated
     */
    poll(): T | undefined;
}
